@@ -178,8 +178,6 @@ class ARDMediathekIE(InfoExtractor):
             ('>Leider liegt eine Störung vor.', 'Video %s is unavailable'),
             ('>Der gewünschte Beitrag ist nicht mehr verfügbar.<',
              'Video %s is no longer available'),
-            ('Diese Sendung ist für Jugendliche unter 12 Jahren nicht geeignet. Der Clip ist deshalb nur von 20 bis 6 Uhr verfügbar.',
-             'This program is only suitable for those aged 12 and older. Video %s is therefore only available between 8 pm and 6 am.'),
         )
 
         for pattern, message in ERRORS:
@@ -255,7 +253,7 @@ class ARDIE(InfoExtractor):
             'duration': 2600,
             'title': 'Die Story im Ersten: Mission unter falscher Flagge',
             'upload_date': '20140804',
-            'thumbnail': 're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.jpg$',
         },
         'skip': 'HTTP Error 404: Not Found',
     }
